@@ -2,7 +2,7 @@
 # PODNAME: App::Prove::Plugin::TestRail
 
 package App::Prove::Plugin::TestRail;
-$App::Prove::Plugin::TestRail::VERSION = '0.041';
+$App::Prove::Plugin::TestRail::VERSION = '0.043';
 use strict;
 use warnings;
 use utf8;
@@ -57,6 +57,7 @@ sub load {
     $ENV{'TESTRAIL_ENCODING'}  = $params->{encoding};
     $ENV{'TESTRAIL_CGROUP'}    = $params->{'configuration_group'};
     $ENV{'TESTRAIL_TBAD'}      = $params->{'test_bad_status'};
+    $ENV{'TESTRAIL_MAX_TRIES'} = $params->{'max_tries'};
     return $class;
 }
 
@@ -74,7 +75,7 @@ App::Prove::Plugin::TestRail - Upload your TAP results to TestRail in realtime
 
 =head1 VERSION
 
-version 0.041
+version 0.043
 
 =head1 SYNOPSIS
 
@@ -106,6 +107,7 @@ If \$HOME/.testrailrc exists, it will be parsed for any of these values in a new
     encoding=UTF-8
     configuration_group=Operating Systems
     test_bad_status=blocked
+    max_tries=3
 
 Note that passing configurations as filters for runs inside of plans are separated by colons.
 
@@ -161,12 +163,12 @@ George S. Baugh <teodesian@cpan.org>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/teodesian/TestRail-Perl>
-and may be cloned from L<git://github.com/teodesian/TestRail-Perl.git>
+The development version is on github at L<http://https://github.com/teodesian/TestRail-Perl>
+and may be cloned from L<git://https://github.com/teodesian/TestRail-Perl.git>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by George S. Baugh.
+This software is copyright (c) 2018 by George S. Baugh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
