@@ -1,7 +1,7 @@
 # ABSTRACT: TestRail testing harness
 # PODNAME: Test::Rail::Harness
 package Test::Rail::Harness;
-$Test::Rail::Harness::VERSION = '0.041';
+$Test::Rail::Harness::VERSION = '0.043';
 use strict;
 use warnings;
 
@@ -40,6 +40,7 @@ sub make_parser {
     $args->{'testsuite'}       = $ENV{'TESTRAIL_TESTSUITE'};
     $args->{'config_group'}    = $ENV{'TESTRAIL_CGROUP'};
     $args->{'test_bad_status'} = $ENV{'TESTRAIL_TBAD'};
+    $args->{'max_tries'}       = $ENV{'TESTRAIL_MAX_TRIES'};
 
     @sections = split( /:/, $ENV{'TESTRAIL_SECTIONS'} )
       if $ENV{'TESTRAIL_SECTIONS'};
@@ -81,7 +82,7 @@ Test::Rail::Harness - TestRail testing harness
 
 =head1 VERSION
 
-version 0.041
+version 0.043
 
 =head1 DESCRIPTION
 
@@ -117,12 +118,12 @@ George S. Baugh <teodesian@cpan.org>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/teodesian/TestRail-Perl>
-and may be cloned from L<git://github.com/teodesian/TestRail-Perl.git>
+The development version is on github at L<http://https://github.com/teodesian/TestRail-Perl>
+and may be cloned from L<git://https://github.com/teodesian/TestRail-Perl.git>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by George S. Baugh.
+This software is copyright (c) 2018 by George S. Baugh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
